@@ -258,6 +258,13 @@ An alias to font property for the hint label widget.
 Selects the timeout in milliseconds before the hint label is shown
 when the mouse pointer hovers over a widget.
 
+=item language STRING
+
+By default contains user interface language, deduced either from C<$ENV{LANG}>
+or GUI default. When changed, updates C<textDirection> propertly.
+
+See also: C<get_system_info>.
+
 =item modalHorizon BOOLEAN
 
 A read-only property. Used as a landmark for
@@ -305,6 +312,16 @@ property in Prima::Widget, Prima::Application::showHint is another layer of
 hint visibility control - if it is 0, all hint actions are disabled,
 disregarding C<::showHint> value in widgets.
 
+=item textDirection BOOLEAN
+
+Contains preferred text direction, initially calculated from the preferred
+interface language.  If 0 ( default ), the preferred text direction is
+left-to-right (LTR), otherwise right-to-left (RTL), f.ex. for arabic and hebrew
+languages.
+
+The value is used as a default when shaping text and setting widget input
+direction.
+
 =item uiScaling FLOAT
 
 The property contains an advisory multiplier factor, useful for UI elements
@@ -328,7 +345,7 @@ operating system do not support UTF8.
 If 1, C<Prima::Clipboard::text> property may return UTF8 text from system
 clipboards is available.
 
-Default value: 0
+Default value: 1
 
 =back
 
@@ -336,6 +353,19 @@ Default value: 0
 
 =over
 
+=item Clipboard $CLIPBOARD, $ACTION, $TARGET
+
+With (the only implemented) C<$ACTION> I<copy>, is called whenever another
+application requests clipboard data in format C<$TARGET>. This notification is
+handled internally to optimize image pasting through the cliboard. Since the
+clipboard pasting semantics in Prima is such that data must be supplied to the
+clipboard in advance, before another application can request it, there is a
+problem which format to use. In order to not encode an image or other complex
+data in all possible formats but do that on demand and in the format the other
+application wants, this notification can be used.
+
+Only implemented for X11.
+
 =item CopyImage $CLIPBOARD, $IMAGE
 
 The notification stores C<$IMAGE> in clipboard.
@@ -580,8 +610,11 @@ user interface used in the system:
 
 =item guiDescription
 
-Description of graphic user interface,
-returned as an arbitrary string.
+Description of graphic user interface, returned as an arbitrary string.
+
+=item guiLanguage
+
+Preferred language of the interface, returned as an ISO 639 code.
 
 =item system
 
@@ -652,8 +685,10 @@ of C<sv::XXX> constants. The constants are:
 	sv::CompositeDisplay - 1 if system uses double-buffering and alpha composition for the desktop,
 	                       0 if it doesn't, -1 if unknown
 	sv::LayeredWidgets   - 1 if system supports layering
-	sv::DWM              - 1 if system supports DWM API
 	sv::FixedPointerSize - 0 if system doesn't support arbitrary sized pointers and will resize custom icons to the system size
+	sv::MenuCheckSize    - width and height of default menu check icon
+	sv::FriBidi          - 1 if Prima is compiled with libfribidi and full bidi unicode support is available
+	sv::Antialias        - 1 if system supports antialiasing and alpha layer for primitives
 
 The method can be called with a class string instead of an object instance.
 
@@ -674,8 +709,8 @@ The main event loop. Called by
 
 run Prima;
 
-standard code. Returns when the program is about to terminate, or if the
-exception was signaled. In the latter case, the loop can be safely re-started.
+standard code. Returns when the program is about to terminate, if C<stop> was called, or if the
+exception was signaled. In the latter two cases, the loop can be safely re-started.
 
 =item lock
 
@@ -702,6 +737,10 @@ link POD format ( see L<perlpod> ) - the string is treated
 as "manpage/section", where 'manpage' is the file with POD
 content and 'section' is the topic inside the manpage.
 
+=item stop
+
+Breaks the event loop. The loop can be started again by C<go> thereafter.
+
 =item sync
 
 Synchronizes all pending requests where there are any. Is an effective
