@@ -31,6 +31,7 @@ sub from_rgb { ($_[2] & 0xff) | (($_[1] & 0xff) << 8) | (($_[0] & 0xff) << 16) }
 sub to_rgb   { (( $_[0]>>16) & 0xFF, ($_[0]>>8) & 0xFF, $_[0] & 0xFF) }
 sub from_bgr { ($_[0] & 0xff) | (($_[1] & 0xff) << 8) | (($_[2] & 0xff) << 16) }
 sub to_bgr   { ($_[0] & 0xFF, ($_[0]>>8) & 0xFF, ( $_[0]>>16) & 0xFF) }
+sub premultiply { from_rgb( map { int($_ * $_[1] / 255) } to_rgb($_[0]) ) }
 
 package
     ci; *AUTOLOAD =  \&Prima::Const::AUTOLOAD;	# color indices
@@ -384,9 +385,9 @@ See L<Prima::Widget/pointerType>
 	cr::SizeSW                  down-right move action pointer
 	cr::Invalid                 invalid action pointer
 	cr::DragNone                pointer for an invalid dragging target
-	cr::DragCopy                pointer to show that a dnd::Copy action can be accepted
-	cr::DragMove                pointer to show that a dnd::Move action can be accepted
-	cr::DragLink                pointer to show that a dnd::Link action can be accepted
+	cr::DragCopy                pointer to indicate that a dnd::Copy action can be accepted
+	cr::DragMove                pointer to indicate that a dnd::Move action can be accepted
+	cr::DragLink                pointer to indicate that a dnd::Link action can be accepted
 	cr::User                    user-defined icon
 
 =head2 dbt::  - device bitmap types
@@ -470,7 +471,7 @@ See L<Prima::Utils/query_drive_type>
 
 =head2 fdo:: - find / replace dialog options
 
-See L<Prima::EditDialog>
+See L<Prima::FindDialog>
 
 	fdo::MatchCase
 	fdo::WordsOnly
@@ -480,7 +481,7 @@ See L<Prima::EditDialog>
 
 =head2 fds:: - find / replace dialog scope type
 
-See L<Prima::EditDialog>
+See L<Prima::FindDialog>
 
 	fds::Cursor
 	fds::Top
@@ -755,6 +756,23 @@ See L<Prima::Image/stats>.
 	is::Sum      - sum of pixel values
 	is::Sum2     - sum of squares of pixel values
 
+=head2 ist:: - image scaling types
+
+	ist::None      - image stripped or padded with zeros
+	ist::Box       - image will be scaled using simple box transform
+	ist::BoxX      - columns behave as ist::None, rows as ist::Box
+	ist::BoxY      - rows behave as in ist::None, columns as ist::Box
+	ist::AND       - shrunken pixels AND-end together (black on white)
+	ist::OR        - shrunken pixels OR-end together (white on black) 
+	ist::Triangle  - bilinear interpolation
+	ist::Quadratic - 2rd order (quadratic) B-Spline approximation of Gaussian
+	ist::Sinc      - sine function
+	ist::Hermite   - B-Spline interpolation
+	ist::Cubic     - 3rd order (cubic) B-Spline approximation of Gaussian
+	ist::Gaussian  - Gaussian transform with gamma=0.5
+
+See L<Prima::Image/scaling>.
+
 =head2 kb::  - keyboard virtual codes
 
 See also L<Prima::Widget/KeyDown>.
@@ -888,6 +906,7 @@ See also L<Prima::Window/modalResult>, L<Prima::Button/modalResult>.
 	mb::OKCancel, mb::OkCancel
 	mb::YesNo
 	mb::YesNoCancel
+	mb::ChangeAll
 
 =item Message box icon and bell constants
 
@@ -1033,6 +1052,14 @@ See also L<Prima::StdBitmap>.
 	sbmp::SFolderClosed
 	sbmp::Last
 
+=head2 scr:: - scroll exposure results
+
+C<Widget::scroll> returns one of these.
+	
+	scr::Error           - failure
+	scr::NoExpose        - call resulted in no new exposed areas
+	scr::Expose          - call resulted in new exposed areas, expect a repaint
+
 =head2 sv::  - system value indices
 
 See also L<Prima::Application/get_system_value>
@@ -1075,10 +1102,10 @@ See also L<Prima::Application/get_system_value>
 	sv::CompositeDisplay - 1 if system uses double-buffering and alpha composition for the desktop,
 	                       0 if it doesn't, -1 if unknown
 	sv::LayeredWidgets   - 1 if system supports layering
-	sv::DWM              - 1 if system supports DWM API
 	sv::FixedPointerSize - 0 if system doesn't support arbitrary sized pointers and will resize custom icons to the system size
 	sv::MenuCheckSize    - width and height of default menu check icon
 	sv::FriBidi          - 1 if Prima is compiled with libfribidi and full bidi unicode support is available
+	sv::Antialias        - 1 if system supports antialiasing and alpha layer for primitives
 
 =head2 ta::  - alignment constants
 
