@@ -56,7 +56,7 @@ sub profile_default
 		dragable       => 1,
 		hScroll        => 0,
 		focusedItem    => -1,
-		indent         => 12,
+		indent         => int( 12 * $::application->uiScaling + .5),
 		itemHeight     => $def-> {font}-> {height},
 		items          => [],
 		multiSelect    => 0,
@@ -75,6 +75,32 @@ sub profile_default
 	return $def;
 }
 
+sub init_images
+{
+	return if @images;
+
+	my $i = 0;
+	my $uis = $::application->uiScaling;
+	@imageSize = map { $uis * $_ } (11,11);
+	my $xd = int(2 * $uis + .5);
+	my $lw = int( $uis + .5);
+	my @c = map { $_ / 2 } @imageSize;
+	for my $i (0,1) {
+		$images[$i] = Prima::DeviceBitmap->new(
+			size      => \@imageSize,
+			backColor => cl::White,
+			color     => cl::Gray,
+		);
+		$images[$i]->clear;
+		$images[$i]->lineWidth($lw);
+		$images[$i]->lineEnd(le::Square);
+		$images[$i]->rectangle(0,0,$imageSize[0]-$lw%2,$imageSize[1]-$lw%2);
+		$images[$i]->color(cl::Black);
+		$images[$i]->line( $xd, $c[1], $imageSize[0]-$xd-1, $c[1] );
+	}
+	$images[1]->line( $c[0], $xd, $c[0], $imageSize[1]-$xd-1);
+}
+
 sub profile_check_in
 {
 	my ( $self, $p, $default) = @_;
@@ -95,31 +121,7 @@ use constant STACK_FRAME => 64;
 sub init
 {
 	my $self = shift;
-	unless ( @images) {
-		my $i = 0;
-		for ( sbmp::OutlineCollapse, sbmp::OutlineExpand) {
-			$images[ $i++] = Prima::StdBitmap::image($_);
-		}
-		if ( $images[0]) {
-			@imageSize = $images[0]-> size;
-		} else {
-			# if compiled without gif support
-			@imageSize = map { $::application->uiScaling * $_ } (11,11);
-			for my $i (0,1) {
-				$images[$i] = Prima::DeviceBitmap->new(
-					width     => $imageSize[0],
-					height    => $imageSize[1],
-					backColor => cl::White,
-					color     => cl::Gray,
-				);
-				$images[$i]->clear;
-				$images[$i]->rectangle(0,0,10,10);
-				$images[$i]->color(cl::Black);
-				$images[$i]->line( 2, 5, 8, 5 );
-			}
-			$images[1]->line( 5, 2, 5, 8);
-		}
-	}
+	init_images;
 	for ( qw( topItem focusedItem))
 		{ $self-> {$_} = -1; }
 	for ( qw( autoHScroll autoVScroll scrollTransaction dx dy hScroll vScroll
@@ -788,7 +790,7 @@ sub on_keydown
 			}
 		}
 
-		if ( !($mod & ~km::Shift))  {
+		if (!($mod & (km::Ctrl|km::Alt))) {
 			my $i;
 			my ( $c, $hit, $items) = ( lc chr $code, undef, $self-> {items});
 			for ( $i = $self-> {focusedItem} + 1; $i < $self-> {count}; $i++)
@@ -1073,12 +1075,12 @@ sub set_focused_item
 			$topSet = $foc - $rows + 1;
 		}
 	}
-	$self-> topItem( $topSet) if defined $topSet;
 	( $oldFoc, $foc) = ( $foc, $oldFoc) if $foc > $oldFoc;
 	my @a  = $self-> get_active_area;
 	my $ih = $self-> {itemHeight};
 	my $lastItem = $self-> {topItem} + $self-> {rows};
-	$self->redraw_items($oldFoc, $foc);
+	$self-> redraw_items($oldFoc, $foc);
+	$self-> topItem( $topSet) if defined $topSet;
 }
 
 sub set_indent
@@ -1646,10 +1648,10 @@ sub draw_items
 			$self->backColor($bc);
 			my $c = $canvas-> color;
 			$canvas-> color( $selected ? $self-> hiliteColor : $c );
-			$canvas-> text_out_bidi( $node-> [0], $left, $bottom);
+			$canvas-> text_shape_out( $node-> [0], $left, $bottom);
 			$canvas-> color( $c);
 		} else {
-			$canvas-> text_out_bidi( $node-> [0], $left, $bottom);
+			$canvas-> text_shape_out( $node-> [0], $left, $bottom);
 		}
 		$canvas-> rect_focus( $left, $bottom, $right, $top) if $focused;
 	}
@@ -1686,10 +1688,10 @@ sub draw_items
 
 			my $c  = $canvas-> color;
 			$canvas-> color( $selected ? $self-> hiliteColor : $c );
-			$canvas-> text_out_bidi( $node-> [0]-> [0], $left, $bottom);
+			$canvas-> text_shape_out( $node-> [0]-> [0], $left, $bottom);
 			$canvas-> color( $c);
 		} else {
-			$canvas-> text_out_bidi( $node-> [0]-> [0], $left, $bottom);
+			$canvas-> text_shape_out( $node-> [0]-> [0], $left, $bottom);
 		}
 		$canvas-> rect_focus( $left, $bottom, $right, $top) if $focused;
 	}
@@ -1819,7 +1821,7 @@ sub draw_items
 			int($bottom + ( $self-> {itemHeight} - $self-> {iconSizes}-> [1]) / 2),
 			$icon
 		);
-		$canvas-> text_out_bidi(
+		$canvas-> text_shape_out(
 			$node-> [0]-> [0],
 			$left + $dw,
 			int($bottom + ( $self-> {itemHeight} - $self-> {fontHeight}) / 2)
@@ -2093,7 +2095,7 @@ Prima::Outlines - tree view widgets
 	$outline-> expand_all;
 	run Prima;
 
-=for podview <img src="outline.gif" cut=1>
+=for podview <img src="outline.gif">
 
 =for html <p><img src="https://raw.githubusercontent.com/dk/Prima/master/pod/Prima/outline.gif">
 
